
From: Dmitry Torokhov <dtor_core@ameritech.net>

Input: rename serio_{register|unregister}_slave_port to 
       __serio_{register|unregister}_port to better follow
       locked/lockless naming convention



 25-akpm/drivers/input/mouse/synaptics.c |    4 ++--
 25-akpm/drivers/input/serio/serio.c     |   23 ++++++++++-------------
 25-akpm/include/linux/serio.h           |    4 ++--
 3 files changed, 14 insertions(+), 17 deletions(-)

diff -puN drivers/input/mouse/synaptics.c~serio-01-renaming drivers/input/mouse/synaptics.c
--- 25/drivers/input/mouse/synaptics.c~serio-01-renaming	Thu Oct  9 01:46:11 2003
+++ 25-akpm/drivers/input/mouse/synaptics.c	Thu Oct  9 01:46:11 2003
@@ -294,7 +294,7 @@ int synaptics_pt_init(struct psmouse *ps
 	port->driver = psmouse;
 
 	printk(KERN_INFO "serio: %s port at %s\n", port->name, psmouse->phys);
-	serio_register_slave_port(port);
+	__serio_register_port(port);	/* already have serio_sem */
 
 	/* adjust the touchpad to child's choice of protocol */
 	child = port->private;
@@ -406,7 +406,7 @@ void synaptics_disconnect(struct psmouse
 	if (psmouse->type == PSMOUSE_SYNAPTICS && priv) {
 		synaptics_mode_cmd(psmouse, 0);
 		if (priv->ptport) {
-			serio_unregister_slave_port(priv->ptport);
+			__serio_unregister_port(priv->ptport); /* already have serio_sem */
 			kfree(priv->ptport);
 		}
 		kfree(priv);
diff -puN drivers/input/serio/serio.c~serio-01-renaming drivers/input/serio/serio.c
--- 25/drivers/input/serio/serio.c~serio-01-renaming	Thu Oct  9 01:46:11 2003
+++ 25-akpm/drivers/input/serio/serio.c	Thu Oct  9 01:46:11 2003
@@ -49,9 +49,9 @@ MODULE_LICENSE("GPL");
 
 EXPORT_SYMBOL(serio_interrupt);
 EXPORT_SYMBOL(serio_register_port);
-EXPORT_SYMBOL(serio_register_slave_port);
+EXPORT_SYMBOL(__serio_register_port);
 EXPORT_SYMBOL(serio_unregister_port);
-EXPORT_SYMBOL(serio_unregister_slave_port);
+EXPORT_SYMBOL(__serio_unregister_port);
 EXPORT_SYMBOL(serio_register_device);
 EXPORT_SYMBOL(serio_unregister_device);
 EXPORT_SYMBOL(serio_open);
@@ -163,17 +163,16 @@ irqreturn_t serio_interrupt(struct serio
 void serio_register_port(struct serio *serio)
 {
 	down(&serio_sem);
-	list_add_tail(&serio->node, &serio_list);
-	serio_find_dev(serio);
+	__serio_register_port(serio);
 	up(&serio_sem);
 }
 
 /*
- * Same as serio_register_port but does not try to acquire serio_sem.
- * Should be used when registering a serio from other input device's
+ * Should only be called directly if serio_sem has already been taken,
+ * for example when unregistering a serio from other input device's
  * connect() function.
  */
-void serio_register_slave_port(struct serio *serio)
+void __serio_register_port(struct serio *serio)
 {
 	list_add_tail(&serio->node, &serio_list);
 	serio_find_dev(serio);
@@ -182,18 +181,16 @@ void serio_register_slave_port(struct se
 void serio_unregister_port(struct serio *serio)
 {
 	down(&serio_sem);
-	list_del_init(&serio->node);
-	if (serio->dev && serio->dev->disconnect)
-		serio->dev->disconnect(serio);
+	__serio_unregister_port(serio);
 	up(&serio_sem);
 }
 
 /*
- * Same as serio_unregister_port but does not try to acquire serio_sem.
- * Should be used when unregistering a serio from other input device's
+ * Should only be called directly if serio_sem has already been taken,
+ * for example when unregistering a serio from other input device's
  * disconnect() function.
  */
-void serio_unregister_slave_port(struct serio *serio)
+void __serio_unregister_port(struct serio *serio)
 {
 	list_del_init(&serio->node);
 	if (serio->dev && serio->dev->disconnect)
diff -puN include/linux/serio.h~serio-01-renaming include/linux/serio.h
--- 25/include/linux/serio.h~serio-01-renaming	Thu Oct  9 01:46:11 2003
+++ 25-akpm/include/linux/serio.h	Thu Oct  9 01:46:11 2003
@@ -61,9 +61,9 @@ void serio_rescan(struct serio *serio);
 irqreturn_t serio_interrupt(struct serio *serio, unsigned char data, unsigned int flags, struct pt_regs *regs);
 
 void serio_register_port(struct serio *serio);
-void serio_register_slave_port(struct serio *serio);
+void __serio_register_port(struct serio *serio);
 void serio_unregister_port(struct serio *serio);
-void serio_unregister_slave_port(struct serio *serio);
+void __serio_unregister_port(struct serio *serio);
 void serio_register_device(struct serio_dev *dev);
 void serio_unregister_device(struct serio_dev *dev);
 

_
